@@ -82,15 +82,17 @@ class FaceDetectionStub(Stub):
             destination='face_detection'
         )
 
-    def find(self, detected_object_id:int, image_key:str, x:int, y:int, w:int, h:int) -> None:
+    def to_train(self):
         self._send(
-            primitive='find',  
+            primitive='to_train',  
+            content={}
+        )
+
+    def to_recognize(self, detected_object_class_id:int, image_key:str) -> None:
+        self._send(
+            primitive='to_recognize',  
             content={
-                'detected_object_id': detected_object_id,
-                'image_key': image_key,
-                'x': x,
-                'y': y,
-                'w': w,
-                'h': h
+                'detected_object_class_id': detected_object_class_id,
+                'image_key': image_key
             }
         )
\ No newline at end of file
